@@ -11,6 +11,7 @@ class _CMMCoreSignaler:
     propertyChanged = Signal(str, str, str)
     channelGroupChanged = Signal(str)
     configGroupChanged = Signal(str, str)
+    configSet = Signal(str, str)
     systemConfigurationLoaded = Signal()
     pixelSizeChanged = Signal(float)
     pixelSizeAffineChanged = Signal(float, float, float, float, float, float)
@@ -23,7 +24,7 @@ class _CMMCoreSignaler:
 
     # added for CMMCorePlus
     sequenceStarted = Signal(MDASequence)  # at the start of an MDA sequence
-    sequencePauseToggled = Signal(MDASequence, bool)  # when MDA is paused/unpaused
+    sequencePauseToggled = Signal(bool)  # when MDA is paused/unpaused
     sequenceCanceled = Signal(MDASequence)  # when mda is canceled
     sequenceFinished = Signal(MDASequence)  # when mda is done (whether canceled or not)
     frameReady = Signal(np.ndarray, MDAEvent)  # after each event in the sequence
